==> apache-paimon-0.6.0-incubating-src.tgz: paimon-0.6.0-incubating/paimon-spark/paimon-spark-common/src/main/scala/org/apache/paimon/spark/PaimonScanBuilder.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.paimon.spark

import org.apache.paimon.table.{AppendOnlyFileStoreTable, Table}
import org.apache.paimon.table.source.ReadBuilder

import org.apache.spark.sql.connector.read.{Scan, SupportsPushDownLimit}

class PaimonScanBuilder(table: Table)
  extends PaimonBaseScanBuilder(table)
  with SupportsPushDownLimit {

  private var pushDownLimit: Option[Int] = None

  override protected def getReadBuilder(): ReadBuilder = {
    val readBuilder = super.getReadBuilder()
    pushDownLimit.foreach(readBuilder.withLimit)
    readBuilder
  }

  override def pushLimit(limit: Int): Boolean = {
    if (table.isInstanceOf[AppendOnlyFileStoreTable]) {
      pushDownLimit = Some(limit)
    }
    // just make a best effort to push down limit
    false
  }
}

==> apache-paimon-0.6.1-incubating-src.tgz: paimon-0.6.1-incubating/paimon-spark/paimon-spark-common/src/main/scala/org/apache/paimon/spark/PaimonScanBuilder.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.paimon.spark

import org.apache.paimon.table.{AppendOnlyFileStoreTable, Table}
import org.apache.paimon.table.source.ReadBuilder

import org.apache.spark.sql.connector.read.SupportsPushDownLimit

class PaimonScanBuilder(table: Table)
  extends PaimonBaseScanBuilder(table)
  with SupportsPushDownLimit {

  private var pushDownLimit: Option[Int] = None

  override protected def getReadBuilder: ReadBuilder = {
    val readBuilder = super.getReadBuilder
    pushDownLimit.foreach(readBuilder.withLimit)
    readBuilder
  }

  override protected def getDescription: String = {
    super.getDescription + pushDownLimit.map(limit => s" Limit: [$limit]").getOrElse("")
  }

  override def pushLimit(limit: Int): Boolean = {
    if (table.isInstanceOf[AppendOnlyFileStoreTable]) {
      pushDownLimit = Some(limit)
    }
    // just make a best effort to push down limit
    false
  }
}
